@@ -25,6 +25,7 @@
 
 namespace YODA {
 
+
   const size_t SEARCH_SIZElc = 16;
   const size_t BISECT_LINEAR_THRESHOLDlc = 32;
 
@@ -95,7 +96,7 @@ namespace YODA {
     using const_iterator = typename ContainerT::const_iterator;
 
     /// @name Constructors
-    //@{
+    /// @{
 
     /// @brief Nullary constructor for unique pointers etc.
     Axis() { }
@@ -131,10 +132,10 @@ namespace YODA {
       return *this;
     }
 
-    //@}
+    /// @}
 
     /// @name I/O
-    // @{
+    /// @{
 
     void _renderYODA(std::ostream& os) const noexcept {
       os << "[";
@@ -165,7 +166,7 @@ namespace YODA {
       return maxwidth;
     }
 
-    //@}
+    /// @}
 
     /// @brief Returns index of edge x
     ///
@@ -188,7 +189,7 @@ namespace YODA {
     size_t size() const noexcept;
 
     /// @brief Returns number of bins of this axis
-    size_t numBins(const bool includeOverflows = false) const noexcept;
+    size_t numBins(const bool includeOverflows=false) const noexcept;
 
     /// @brief Checks if two axes have exactly the same edges
     bool hasSameEdges(const Axis<T>& other) const noexcept;
@@ -205,12 +206,12 @@ namespace YODA {
     protected:
 
     /// @name Utility
-    // @{
+    /// @{
 
     /// @brief Fills edge storage. Used in constructors.
     void fillEdges(std::vector<EdgeT>&& edges) noexcept;
 
-    // @}
+    /// @}
 
     /// @brief Axis edges
     std::vector<T> _edges;
@@ -218,7 +219,7 @@ namespace YODA {
   };
 
 
-  // @todo Document!
+  /// @todo Document!
   template <typename T, typename U>
   Axis<T, U>::Axis(const std::vector<T>& edges) : Axis(std::vector<T>(edges)) {
       /// @brief Concept check shall appear inside body of type's member function
@@ -409,13 +410,13 @@ namespace YODA {
     ///
     size_t index(const EdgeT& x) const;
 
-    /// @brief Returns amount of bins in axis
+    /// @brief Returns number of edges + 2 for this Axis
     size_t size() const noexcept;
 
-    /// @brief Returns amount of bins in axis
-    size_t numBins(const bool includeOverflows = false) const noexcept;
+    /// @brief Returns number of bins of this axis
+    size_t numBins(const bool includeOverflows=false) const noexcept;
 
-    /// @brief Returns edge corresponding to index
+    /// @brief Returns edge corresponding to index @a i
     EdgeT edge(const size_t i) const;
 
     /// @brief Returns a copy of all axis edges. Includes -inf and +inf edges.
@@ -449,7 +450,7 @@ namespace YODA {
     // }
 
     /// @name I/O
-    // @{
+    /// @{
 
     void _renderYODA(std::ostream& os) const noexcept {
       os << "[";
@@ -466,22 +467,23 @@ namespace YODA {
     /// @brief Returns a string representation of EdgeT
     std::string type() const noexcept { return TypeID<EdgeT>::name(); }
 
-    // @}
+    /// @}
 
     /// @name Transformations
-    // @{
+    /// @{
 
     /// @brief Merges bins, e.g. removes edges in between.
     ///
     /// @note At least 1 non-overflow bin must exist after merging.
     void mergeBins(std::pair<size_t, size_t>);
 
-    // @}
+    /// @}
 
     /// @name Space characteristics
-    // @{
+    /// @{
 
-    std::vector<T> widths(const bool includeOverflows = false) const noexcept {
+    /// @brief List of bin widths on this axis.
+    std::vector<T> widths(const bool includeOverflows=false) const noexcept {
       // number of widths = number of edges - 1
       // unless you exclude under-/overflow
       size_t offset = includeOverflows? 1 : 3;
@@ -494,6 +496,48 @@ namespace YODA {
       return ret;
     }
 
+    /// @brief List of max values for each bin on this axis.
+    std::vector<T> maxs(const bool includeOverflows=false) const noexcept {
+      // number of maxs = number of edges - 1
+      // unless you exclude under-/overflow
+      size_t offset = includeOverflows? 1 : 3;
+      std::vector<T> ret(_edges.size()-offset);
+      size_t start = 1 + !includeOverflows;
+      size_t end = _edges.size() - !includeOverflows;
+      for (size_t i = start; i < end; ++i) {
+        ret[i-start] = _edges[i];
+      }
+      return ret;
+    }
+
+    /// @brief List of min values for each bin on this axis.
+    std::vector<T> mins(const bool includeOverflows=false) const noexcept {
+      // number of mins = number of edges - 1
+      // unless you exclude under-/overflow
+      size_t offset = includeOverflows? 1 : 3;
+      std::vector<T> ret(_edges.size()-offset);
+      size_t start = 1 + !includeOverflows;
+      size_t end = _edges.size() - !includeOverflows;
+      for (size_t i = start; i < end; ++i) {
+        ret[i-start] = _edges[i-1];
+      }
+      return ret;
+    }
+
+    /// @brief List of mid values for each bin on this axis.
+    std::vector<T> mids(const bool includeOverflows=false) const noexcept {
+      // number of mins = number of edges - 1
+      // unless you exclude under-/overflow
+      size_t offset = includeOverflows? 1 : 3;
+      std::vector<T> ret(_edges.size()-offset);
+      size_t start = 1 + !includeOverflows;
+      size_t end = _edges.size() - !includeOverflows;
+      for (size_t i = start; i < end; ++i) {
+        ret[i-start] = 0.5*(_edges[i-1] + _edges[i]);
+      }
+      return ret;
+    }
+
     /// @brief Width of bin side on this axis.
     EdgeT width(size_t binNum) const noexcept {
       return _edges[binNum+1] - _edges[binNum];
@@ -521,7 +565,7 @@ namespace YODA {
       EdgeT minVal = min(binNum);
       return (max(binNum) - minVal)/2 + minVal;
     }
-    // @}
+    /// @}
 
     protected:
 
@@ -811,8 +855,8 @@ namespace YODA {
       // Calculate mean index estimate deviations from the correct answers (for bin edges)
       double logsum = 0, linsum = 0;
       for (int i = front; i <= back; ++i) {
-        logsum += abs(logEst(_edges[i]) - double(i-1));
-        linsum += abs(linEst(_edges[i]) - double(i-1));
+        logsum += std::abs(logEst(_edges[i]) - double(i-1));
+        linsum += std::abs(linEst(_edges[i]) - double(i-1));
       }
       const double log_avg = logsum / _edges.size();
       const double lin_avg = linsum / _edges.size();
