@@ -22,9 +22,9 @@
 #include <iostream>
 #include <iomanip>
 
-
 namespace YODA {
 
+
   /// All histograms can be instantiated through this alias.
   /*
   ///               BinnedStorage                : Introduces binning backend.
@@ -272,7 +272,9 @@ namespace YODA {
     ///
     /// @note Only visible bins are being rebinned. Underflow (index = 0) and
     /// overflow (index = numBins() + 1) are not included.
-    template <size_t axisN>
+    ///
+    /// @note Only supported for continuous axes
+    template <size_t axisN, typename = std::enable_if_t<BinningT::template is_CAxis<axisN>::value>>
     void rebinBy(unsigned int n, size_t begin=1, size_t end=UINT_MAX) {
       if (n < 1)  throw UserError("Rebinning requested in groups of 0!");
       if (!begin) throw UserError("Visible bins start with index 1!");
@@ -288,13 +290,17 @@ namespace YODA {
     }
 
     /// @brief Overloaded alias for rebinBy
-    template <size_t axisN>
+    ///
+    /// @note Only supported for continuous axes
+    template <size_t axisN, typename = std::enable_if_t<BinningT::template is_CAxis<axisN>::value>>
     void rebin(unsigned int n, size_t begin=1, size_t end=UINT_MAX) {
       rebinBy<axisN>(n, begin, end);
     }
 
     /// @brief Rebin to the given list of bin edges
-    template <size_t axisN>
+    ///
+    /// @note Only supported for continuous axes
+    template <size_t axisN, typename = std::enable_if_t<BinningT::template is_CAxis<axisN>::value>>
     void rebinTo(const std::vector<typename BinningT::template getAxisT<axisN>::EdgeT>& newedges) {
       if (newedges.size() < 2)
         throw UserError("Requested rebinning to an edge list which defines no bins");
@@ -321,7 +327,9 @@ namespace YODA {
     }
 
     /// @brief Overloaded alias for rebinTo
-    template <size_t axisN>
+    ///
+    /// @note Only supported for continuous axes
+    template <size_t axisN, typename = std::enable_if_t<BinningT::template is_CAxis<axisN>::value>>
     void rebin(const std::vector<typename BinningT::template getAxisT<axisN>::EdgeT>& newedges) {
       rebinTo<axisN>(newedges);
     }
@@ -424,40 +432,6 @@ namespace YODA {
     /// @brief Returns the axis configuration
     std::string _config() const noexcept { return mkAxisConfig<AxisT...>(); }
 
-    /// @brief Returns the edges of axis N by value.
-    template <size_t I, typename E = typename BinningT::template getEdgeT<I>>
-    std::vector<E> edges(const bool includeOverflows = false) const noexcept {
-      return BaseT::_binning.template edges<I>(includeOverflows);
-    }
-
-    /// @brief Templated version to get bin widths of axis N by reference.
-    ///
-    /// Overflows are included depending on @a includeOverflows
-    /// Needed by axis-specific version from AxisMixin
-    ///
-    /// @note This version is only supported for continuous axes.
-    template <size_t I, typename E = typename BinningT::template getEdgeT<I>>
-    std::enable_if_t<std::is_floating_point<E>::value, std::vector<E>>
-    widths(const bool includeOverflows = false) const noexcept {
-      return BaseT::_binning.template widths<I>(includeOverflows);
-    }
-
-    /// @brief Get the lowest non-overflow edge of the axis
-    ///
-    /// @note This method is only supported for continuous axes
-    template <size_t I, typename E = typename BinningT::template getEdgeT<I>>
-    std::enable_if_t<std::is_floating_point<E>::value, E> min() const noexcept {
-      return BaseT::_binning.template min<I>();
-    }
-
-    /// @brief Get the highest non-overflow edge of the axis
-    ///
-    /// @note This method is only supported for continuous axes
-    template <size_t I, typename E = typename BinningT::template getEdgeT<I>>
-    std::enable_if_t<std::is_floating_point<E>::value, E> max() const noexcept {
-      return BaseT::_binning.template max<I>();
-    }
-
     /// @}
 
 
@@ -510,32 +484,36 @@ namespace YODA {
     /// @brief Get the number of fills (fractional fills are possible).
     double numEntries(const bool includeOverflows=true) const noexcept {
       double n = 0;
-      for (const auto& b : BaseT::bins(includeOverflows))
+      for (const auto& b : BaseT::bins(includeOverflows)) {
         n += b.numEntries();
+      }
       return n;
     }
 
     /// @brief Get the effective number of fills.
     double effNumEntries(const bool includeOverflows=true) const noexcept {
       double n = 0;
-      for (const auto& b : BaseT::bins(includeOverflows))
+      for (const auto& b : BaseT::bins(includeOverflows)) {
         n += b.effNumEntries();
+      }
       return n;
     }
 
     /// @brief Calculates sum of weights in histo.
     double sumW(const bool includeOverflows=true) const noexcept {
       double sumw = 0;
-      for (const auto& b : BaseT::bins(includeOverflows))
+      for (const auto& b : BaseT::bins(includeOverflows)) {
         sumw += b.sumW();
+      }
       return sumw;
     }
 
     /// @brief Calculates sum of squared weights in histo.
     double sumW2(const bool includeOverflows=true) const noexcept {
       double sumw2 = 0;
-      for (const auto& b : BaseT::bins(includeOverflows))
+      for (const auto& b : BaseT::bins(includeOverflows)) {
         sumw2 += b.sumW2();
+      }
       return sumw2;
     }
 
@@ -543,8 +521,9 @@ namespace YODA {
     double sumWA(const size_t dim, const bool includeOverflows=true) const {
       if (dim >= DbnN)  throw RangeError("Invalid axis int, must be in range 0..dim-1");
       double sumwa = 0;
-      for (const auto& b : BaseT::bins(includeOverflows))
+      for (const auto& b : BaseT::bins(includeOverflows)) {
         sumwa += b.sumW(dim+1);
+      }
       return sumwa;
     }
 
@@ -552,8 +531,9 @@ namespace YODA {
     double sumWA2(const size_t dim, const bool includeOverflows=true) const {
       if (dim >= DbnN)  throw RangeError("Invalid axis int, must be in range 0..dim-1");
       double sumwa2 = 0;
-      for (const auto& b : BaseT::bins(includeOverflows))
+      for (const auto& b : BaseT::bins(includeOverflows)) {
         sumwa2 += b.sumW2(dim+1);
+      }
       return sumwa2;
     }
 
@@ -563,52 +543,69 @@ namespace YODA {
       if (A1 >= DbnN || A2 >= DbnN)  throw RangeError("Invalid axis int, must be in range 0..dim-1");
       if (A1 >= A2)  throw RangeError("Indices need to be different for cross term");
       double sumw = 0;
-      for (const auto& b : BaseT::bins(includeOverflows))
+      for (const auto& b : BaseT::bins(includeOverflows)) {
         sumw += b.crossTerm(A1, A2);
+      }
       return sumw;
     }
 
-    /// @brief Calculates the mean value at axis.
+    /// @brief List of mean values at axis @a axisN.
+    std::vector<double> means(size_t axisN, const bool includeOverflows=true) const noexcept {
+      std::vector<double> rtn;
+      rtn.reserve( BaseT::numBins(includeOverflows) );
+      for (const auto& b : BaseT::bins(includeOverflows)) {
+        rtn.push_back(b.mean(axisN+1));
+      }
+      return rtn;
+    }
+
+    /// @brief Calculates the mean value at axis @a axisN.
     double mean(size_t axisN, const bool includeOverflows=true) const noexcept {
       Dbn<DbnN> dbn;
-      for (const auto& b : BaseT::bins(includeOverflows))
+      for (const auto& b : BaseT::bins(includeOverflows)) {
         dbn += b;
+      }
       return dbn.mean(axisN+1);
     }
 
-    /// @brief Calculates the variance at axis.
+    /// @brief Calculates the variance at axis @a axisN.
     double variance(size_t axisN, const bool includeOverflows=true) const noexcept {
       Dbn<DbnN> dbn;
-      for (const auto& b : BaseT::bins(includeOverflows))
+      for (const auto& b : BaseT::bins(includeOverflows)) {
         dbn += b;
+      }
       return dbn.variance(axisN+1);
     }
 
-    /// @brief Calculates the standard deviation at axis.
+    /// @brief Calculates the standard deviation at axis @a axisN.
     double stdDev(size_t axisN, const bool includeOverflows=true) const noexcept {
       return std::sqrt(variance(axisN, includeOverflows));
     }
 
-    /// @brief Calculates the standard error at axis.
+    /// @brief Calculates the standard error at axis @a axisN.
     double stdErr(size_t axisN, const bool includeOverflows=true) const noexcept {
       Dbn<DbnN> dbn;
-      for (const auto& b : BaseT::bins(includeOverflows))
+      for (const auto& b : BaseT::bins(includeOverflows)) {
         dbn += b;
+      }
       return dbn.stdErr(axisN+1);
     }
 
-    /// @brief Calculates the RMS at axis.
+    /// @brief Calculates the RMS at axis @a axisN.
     double rms(size_t axisN, const bool includeOverflows=true) const noexcept {
       Dbn<DbnN> dbn;
-      for (const auto& b : BaseT::bins(includeOverflows))
+      for (const auto& b : BaseT::bins(includeOverflows)) {
         dbn += b;
+      }
       return dbn.RMS(axisN+1);
     }
 
+    /// @brief Calculates the total volume element covered by the binning.
     double dVol(const bool includeOverflows=true) const noexcept {
       double vol = 0.0;
-      for (const auto& b : BaseT::bins(includeOverflows))
+      for (const auto& b : BaseT::bins(includeOverflows)) {
         vol += b.dVol();
+      }
       return vol;
     }
 
@@ -629,16 +626,18 @@ namespace YODA {
     /// @brief Returns the sum of the bin densities
     double densitySum(const bool includeOverflows=true) const noexcept {
       double rho = 0.0;
-      for (const auto& b : BaseT::bins(includeOverflows))
+      for (const auto& b : BaseT::bins(includeOverflows)) {
         rho += b.sumW() / b.dVol();
+      }
       return rho;
     }
 
     /// @brief Returns the largest density in any of the bins
     double maxDensity(const bool includeOverflows=true) const noexcept {
       std::vector<double> vals;
-      for (auto& b : BaseT::bins(includeOverflows))
+      for (auto& b : BaseT::bins(includeOverflows)) {
         vals.emplace_back(b.sumW() / b.dVol());
+      }
       return *max_element(vals.begin(), vals.end());
     }
 
@@ -649,7 +648,7 @@ namespace YODA {
 
   private:
 
-    // @brief Render information about this AO (private implementation)
+    /// @brief Render information about this AO (private implementation)
     template<size_t... Is>
     void _renderYODA_aux(std::ostream& os, const int width, std::index_sequence<Is...>) const noexcept {
 
@@ -698,19 +697,19 @@ namespace YODA {
 
   public:
 
-    // @brief Render information about this AO (public API)
+    /// @brief Render information about this AO (public API)
     void _renderYODA(std::ostream& os, const int width = 13) const noexcept {
       _renderYODA_aux(os, width, std::make_index_sequence<DbnN>{});
     }
 
-    // @brief Render scatter-like information about this AO
+    /// @brief Render scatter-like information about this AO
     void _renderFLAT(std::ostream& os, const int width = 13) const noexcept {
       const ScatterND<sizeof...(AxisT)+1> tmp = mkScatter();
       tmp._renderYODA(os, width);
     }
 
     #ifdef HAVE_HDF5
-    // @brief Extract axes edges of this AO into map of @a edges
+    /// @brief Extract axes edges of this AO into map of @a edges
     void _extractEdges(std::map<std::string, EdgeHandlerBasePtr>& edges,
                        const std::vector<std::string>&) const noexcept {
 
@@ -750,7 +749,7 @@ namespace YODA {
     /// @}
 
     /// @name MPI (de-)serialisation
-    //@{
+    /// @{
 
     size_t lengthContent(bool = false) const noexcept {
       return BaseT::numBins(true, true) * Dbn<DbnN>::DataSize::value;
@@ -786,7 +785,7 @@ namespace YODA {
 
     }
 
-    // @}
+    /// @}
 
     /// @name Type reductions
     /// @{
@@ -802,7 +801,7 @@ namespace YODA {
                        [[maybe_unused]] const bool divbyvol = true,
                                         const double overflowsWidth = -1.0) const {
 
-      // @todo Should we check BaseT::nanCount() and report?
+      /// @todo Should we check BaseT::nanCount() and report?
       BinnedEstimate<AxisT...> rtn(BaseT::_binning);
       for (const std::string& a : annotations()) {
         if (a != "Type")  rtn.setAnnotation(a, annotation(a));
@@ -1203,7 +1202,7 @@ namespace YODA {
           e = fabs(v) * sqrt(sqr(e_num) + sqr(e_den));
         }
       }
-      rtn.bin(idx).set(v, {-e, e}); // @todo put "stats" as source?
+      rtn.bin(idx).set(v, {-e, e}); ///< @todo put "stats" as source?
     }
     rtn.maskBins(denom.maskedBins(), true);
 
@@ -1266,7 +1265,7 @@ namespace YODA {
         eff = b_rtn.val();
         err = sqrt(fabs( add((1.0-2.0*eff)*b_acc.sumW2(), sqr(eff)*b_tot.sumW2()) / sqr(b_tot.sumW()) ));
       }
-      b_rtn.setErr({-err, err}); // @todo put "stats" as source?
+      b_rtn.setErr({-err, err}); ///< @todo put "stats" as source?
     }
     return rtn;
   }
