@@ -18,9 +18,9 @@
 #include "YODA/Utils/H5Utils.h"
 #endif
 
-
 namespace YODA {
 
+
   /// @note Anonymous namespace to limit visibility to this file
   namespace {
     /// @brief Nullify bin uncertainty for discrete axes
@@ -172,7 +172,7 @@ namespace YODA {
 
   private:
 
-    // @brief Render information about this AO (private implementation)
+    /// @brief Render information about this AO (private implementation)
     template<size_t... Is>
     void _renderYODA_aux(std::ostream& os, const int width, std::index_sequence<Is...>) const noexcept {
 
@@ -227,15 +227,12 @@ namespace YODA {
 
   public:
 
-    /// @name I/O
-    /// @{
-
-    // @brief Render information about this AO
+    /// @brief Render information about this AO
     void _renderYODA(std::ostream& os, const int width = 13) const noexcept {
       _renderYODA_aux(os, width, std::make_index_sequence<sizeof...(AxisT)>{});
     }
 
-    // @brief Render scatter-like information about this AO
+    /// @brief Render scatter-like information about this AO
     void _renderFLAT(std::ostream& os, const int width = 13) const noexcept {
       const ScatterND<sizeof...(AxisT)+1> tmp = mkScatter();
       tmp._renderYODA(os, width);
@@ -243,7 +240,7 @@ namespace YODA {
 
     #ifdef HAVE_HDF5
 
-    // @brief Extract error labels of this AO
+    /// @brief Extract error labels of this AO
     void _extractLabels(std::vector<std::string>& labels,
                         std::vector<size_t>& labelsizes) const noexcept {
       size_t nlabels = 0;
@@ -257,9 +254,9 @@ namespace YODA {
       std::sort(labels.begin(), labels.end());
       labels.erase( std::unique(labels.begin(), labels.end()), labels.end() );
       labelsizes.emplace_back(std::move(nlabels));
-    };
+    }
 
-    // @brief Extract axes edges of this AO into map of @a edges
+    /// @brief Extract axes edges of this AO into map of @a edges
     void _extractEdges(std::map<std::string, EdgeHandlerBasePtr>& edges,
                        const std::vector<std::string>& labels) const noexcept {
 
@@ -330,7 +327,9 @@ namespace YODA {
     ///
     /// @note Only visible bins are being rebinned. Underflow (index = 0) and
     /// overflow (index = numBins() + 1) are not included.
-    template <size_t axisN>
+    ///
+    /// @note Only supported for continuous axes
+    template <size_t axisN, typename = std::enable_if_t<BinningT::template is_CAxis<axisN>::value>>
     void rebinBy(unsigned int n, size_t begin=1, size_t end=UINT_MAX) {
       if (n < 1)  throw UserError("Rebinning requested in groups of 0!");
       if (!begin) throw UserError("Visible bins start with index 1!");
@@ -346,13 +345,17 @@ namespace YODA {
     }
 
     /// @brief Overloaded alias for rebinBy
-    template <size_t axisN>
+    ///
+    /// @note Only supported for continuous axes
+    template <size_t axisN, typename = std::enable_if_t<BinningT::template is_CAxis<axisN>::value>>
     void rebin(unsigned int n, size_t begin=1, size_t end=UINT_MAX) {
       rebinBy<axisN>(n, begin, end);
     }
 
     /// @brief Rebin to the given list of bin edges
-    template <size_t axisN>
+    ///
+    /// @note Only supported for continuous axes
+    template <size_t axisN, typename = std::enable_if_t<BinningT::template is_CAxis<axisN>::value>>
     void rebinTo(const std::vector<typename BinningT::template getAxisT<axisN>::EdgeT>& newedges) {
       if (newedges.size() < 2)
         throw UserError("Requested rebinning to an edge list which defines no bins");
@@ -379,7 +382,9 @@ namespace YODA {
     }
 
     /// @brief Overloaded alias for rebinTo
-    template <size_t axisN>
+    ///
+    /// @note Only supported for continuous axes
+    template <size_t axisN, typename = std::enable_if_t<BinningT::template is_CAxis<axisN>::value>>
     void rebin(const std::vector<typename BinningT::template getAxisT<axisN>::EdgeT>& newedges) {
       rebinTo<axisN>(std::move(newedges));
     }
@@ -497,43 +502,6 @@ namespace YODA {
     /// @brief Returns the axis configuration
     std::string _config() const noexcept { return mkAxisConfig<AxisT...>(); }
 
-    /// @brief Templated version to get edges of axis N by value.
-    /// +-inf edges are included.
-    ///
-    /// @note Needed by axis-specific verison from AxisMixin
-    template <size_t I, typename E = typename BinningT::template getEdgeT<I>>
-    std::vector<E> edges(const bool includeOverflows = false) const noexcept {
-      return BaseT::_binning.template edges<I>(includeOverflows);
-    }
-
-    /// @brief Templated version to get bin widths of axis N by value.
-    ///
-    /// Overflows are included depending on @a includeOverflows
-    /// Needed by axis-specific version from AxisMixin
-    ///
-    /// @note This version is only supported for continuous axes.
-    template <size_t I, typename E = typename BinningT::template getEdgeT<I>>
-    std::enable_if_t<std::is_floating_point<E>::value, std::vector<E>>
-    widths(const bool includeOverflows = false) const noexcept {
-      return BaseT::_binning.template widths<I>(includeOverflows);
-    }
-
-    /// @brief Get the lowest non-overflow edge of the axis
-    ///
-    /// @note This method is only supported for continuous axes
-    template <size_t I, typename E = typename BinningT::template getEdgeT<I>>
-    std::enable_if_t<std::is_floating_point<E>::value, E> min() const noexcept {
-      return BaseT::_binning.template min<I>();
-    }
-
-    /// @brief Get the highest non-overflow edge of the axis
-    ///
-    /// @note This method is only supported for continuous axes
-    template <size_t I, typename E = typename BinningT::template getEdgeT<I>>
-    std::enable_if_t<std::is_floating_point<E>::value, E> max() const noexcept {
-      return BaseT::_binning.template max<I>();
-    }
-
     /// @}
 
 
@@ -594,10 +562,10 @@ namespace YODA {
 
 
     /// @brief Construct a covariance matrix from the error breakdown
-    std::vector<std::vector<double> > covarianceMatrix(const bool ignoreOffDiagonalTerms=false,
-                                                       const bool includeOverflows=false,
-                                                       const bool includeMaskedBins=false,
-                                                       const std::string& pat_uncorr="^stat|^uncor") const {
+    std::vector<std::vector<double>> covarianceMatrix(const bool ignoreOffDiagonalTerms=false,
+                                                      const bool includeOverflows=false,
+                                                      const bool includeMaskedBins=false,
+                                                      const std::string& pat_uncorr="^stat|^uncor") const {
       const size_t nBins = BaseT::numBins(includeOverflows,includeMaskedBins);
       std::vector<std::vector<double> > covM(nBins);
 
@@ -686,8 +654,8 @@ namespace YODA {
           errs[I] = nullifyIfDisc<I>(b, vals[I], std::integral_constant<bool, isContinuous::value>{});
         };
         MetaUtils::staticFor<BinningT::Dimension::value>(nullifyDiscrete);
-        const double tot = fabs(b.totalErrPos(pat_match)); // use positive error component
-        errs[N] = { tot, tot };
+        const std::pair<double,double> tot = b.totalErr(pat_match);
+        errs[N] = {fabs(tot.first), tot.second};
 
         // Add the PointND
         rtn.addPoint( PointND<N+1>(vals, errs) );
@@ -754,7 +722,7 @@ namespace YODA {
     /// @}
 
     /// @name MPI (de-)serialisation
-    //@{
+    /// @{
 
     size_t lengthContent(bool fixed_length = false) const noexcept {
       size_t rtn = 0;
@@ -802,7 +770,7 @@ namespace YODA {
       }
     }
 
-    // @}
+    /// @}
 
   private:
 
