@@ -15,6 +15,7 @@
 
 namespace YODA {
 
+
   /// @brief Vector wrapper used to interact with bins vectors.
   /// Able to hide overflow and hidden bins.
   template <class VecT>
@@ -128,7 +129,7 @@ namespace YODA {
 
 
     /// @name Constructors
-    // @{
+    /// @{
 
     /// @brief Nullary constructor for unique pointers etc.
     BinnedStorage() : _binning(std::vector<AxisT>{}...) {
@@ -180,10 +181,10 @@ namespace YODA {
       fillBins(std::move(other._bins));
     }
 
-    // @}
+    /// @}
 
     /// @name Methods
-    // @{
+    /// @{
 
     /// @brief Total dimension of the object ( = number of axes + content)
     size_t dim() const noexcept {
@@ -265,9 +266,9 @@ namespace YODA {
 
       // define a lambda
       auto appendIndicesVec = [&indicesToSkip](std::vector<size_t>&& indicesVec) {
-      indicesToSkip.insert(std::end(indicesToSkip),
-                           std::make_move_iterator(std::begin(indicesVec)),
-                           std::make_move_iterator(std::end(indicesVec)));
+        indicesToSkip.insert(std::end(indicesToSkip),
+                             std::make_move_iterator(std::begin(indicesVec)),
+                             std::make_move_iterator(std::end(indicesVec)));
       };
 
       // only calculate the masked indices when
@@ -312,10 +313,10 @@ namespace YODA {
                 calcIndicesToSkip(includeOverflows, includeMaskedBins));
     }
 
-    // @}
+    /// @}
 
-    /// @name Utilities
-    // @{
+    /// @name Binning utilities
+    /// @{
 
     /// @brief Returns dimension underlying binning object reference.
     const BinningT& binning() const noexcept {
@@ -352,6 +353,82 @@ namespace YODA {
       fillBins();
     }
 
+    /// @brief Returns the edges of axis N by value.
+    template <size_t I, typename E = typename BinningT::template getEdgeT<I>>
+    std::vector<E> edges(const bool includeOverflows = false) const noexcept {
+      return BaseT::_binning.template edges<I>(includeOverflows);
+    }
+
+    /// @brief Templated version to get bin widths of axis I by value.
+    ///
+    /// Overflows are included depending on @a includeOverflows
+    /// Needed by axis-specific version from AxisMixin
+    ///
+    /// @note This version is only supported for continuous axes.
+    template <size_t I, typename E = typename BinningT::template getEdgeT<I>>
+    std::enable_if_t<std::is_floating_point<E>::value, std::vector<E>>
+    widths(const bool includeOverflows = false) const noexcept {
+      return BaseT::_binning.template widths<I>(includeOverflows);
+    }
+
+    /// @brief Templated version to get bin mins of axis I by value.
+    ///
+    /// Overflows are included depending on @a includeOverflows
+    /// Needed by axis-specific version from AxisMixin
+    ///
+    /// @note This version is only supported for continuous axes.
+    template <size_t I, typename E = typename BinningT::template getEdgeT<I>>
+    std::enable_if_t<std::is_floating_point<E>::value, std::vector<E>>
+    mins(const bool includeOverflows = false) const noexcept {
+      return BaseT::_binning.template mins<I>(includeOverflows);
+    }
+
+    /// @brief Templated version to get bin maxs of axis I by value.
+    ///
+    /// Overflows are included depending on @a includeOverflows
+    /// Needed by axis-specific version from AxisMixin
+    ///
+    /// @note This version is only supported for continuous axes.
+    template <size_t I, typename E = typename BinningT::template getEdgeT<I>>
+    std::enable_if_t<std::is_floating_point<E>::value, std::vector<E>>
+    maxs(const bool includeOverflows = false) const noexcept {
+      return BaseT::_binning.template maxs<I>(includeOverflows);
+    }
+
+    /// @brief Templated version to get bin mids of axis I by value.
+    ///
+    /// Overflows are included depending on @a includeOverflows
+    /// Needed by axis-specific version from AxisMixin
+    ///
+    /// @note This version is only supported for continuous axes.
+    template <size_t I, typename E = typename BinningT::template getEdgeT<I>>
+    std::enable_if_t<std::is_floating_point<E>::value, std::vector<E>>
+    mids(const bool includeOverflows = false) const noexcept {
+      return BaseT::_binning.template mids<I>(includeOverflows);
+    }
+
+    /// @brief Get the lowest non-overflow edge of the axis
+    ///
+    /// @note This method is only supported for continuous axes
+    template <size_t I, typename E = typename BinningT::template getEdgeT<I>>
+    std::enable_if_t<std::is_floating_point<E>::value, E> min() const noexcept {
+      return BaseT::_binning.template min<I>();
+    }
+
+    /// @brief Get the highest non-overflow edge of the axis
+    ///
+    /// @note This method is only supported for continuous axes
+    template <size_t I, typename E = typename BinningT::template getEdgeT<I>>
+    std::enable_if_t<std::is_floating_point<E>::value, E> max() const noexcept {
+      return BaseT::_binning.template max<I>();
+    }
+
+    /// @}
+
+
+    /// @name Bin-masking utilities
+    /// @{
+
     /// @brief Mask a range of bins
     void maskBins(const std::vector<size_t>& indicesToMask, const bool status = true) noexcept {
       _binning.maskBins(indicesToMask, status);
@@ -384,6 +461,12 @@ namespace YODA {
       return _binning.isVisible(binIndex);
     }
 
+    /// @}
+
+
+    /// @name Bin-merging and -slicing utilities
+    /// @{
+
     /// @brief Merge bins from A to B at G axis.
     ///
     /// @param mergeRanges Call using following form mergeBins<1,2>({0, 5}, {3, 4}).
@@ -476,6 +559,11 @@ namespace YODA {
       return rtn;
     }
 
+    /// @}
+
+
+    /// @name Assignment and Boolean operators
+    /// @{
 
     /// @brief Copy assignment
     BinnedStorage& operator = (const BinnedStorage& other) noexcept {
@@ -524,13 +612,13 @@ namespace YODA {
       return _binning.localToGlobalIndex(arr);
     }
 
-    //@}
+    /// @}
 
 
     protected:
 
       /// @name Utilities
-      // @{
+      /// @{
 
       /// @brief Fills bins with wrapped BinContent objects
       void fillBins() noexcept {
@@ -569,7 +657,7 @@ namespace YODA {
         return _mkBinnedT_aux<BinnedT>(t, std::make_index_sequence<sizeof...(newAxes)>{});
       }
 
-      // @}
+      /// @}
 
       /// @brief 1-dim vector, which should be indexed by globalIndex of
       /// the underlying _binning object.
