@@ -14,6 +14,7 @@
 
 namespace YODA {
 
+
   /// @brief Nullifies coordinate if it is discrete.
   template<typename CoordT>
   double nullifyIfDiscCoord(CoordT&& /* coord */, std::false_type, double null = 0.0) {
@@ -56,16 +57,16 @@ namespace YODA {
   protected:
 
     /// @name Utilities
-    // @{
+    /// @{
 
     using IndexArr = std::array<size_t, sizeof...(Axes)>;
 
-    // @}
+    /// @}
 
   public:
 
     /// @name Utilities
-    // @{
+    /// @{
 
     template <size_t I>
     using getAxisT = std::tuple_element_t<I, std::tuple<Axes...>>;
@@ -86,10 +87,10 @@ namespace YODA {
 
     using Dimension = std::integral_constant<size_t, sizeof...(Axes)>;
 
-    // @}
+    /// @}
 
     /// @name Constructors
-    //@{
+    /// @{
 
     /// @brief Nullary constructor for unique pointers etc.
     Binning() { }
@@ -142,10 +143,10 @@ namespace YODA {
       return *this;
     }
 
-    //@}
+    /// @}
 
     /// @name Indexing methods
-    //@{
+    /// @{
 
     /// @brief calculates global index from array of local indices
     size_t localToGlobalIndex(const IndexArr& localIndices) const;
@@ -160,7 +161,12 @@ namespace YODA {
     size_t globalIndexAt(const EdgeTypesTuple& coords) const;
 
     /// @brief Calculates indices of overflow bins.
-    std::vector<size_t> calcOverflowBinsIndices() const noexcept;
+    std::vector<size_t> overflowBins() const noexcept;
+
+    /// @brief Alias for overflowBins.
+    std::vector<size_t> calcOverflowBinsIndices() const noexcept {
+      return overflowBins();
+    }
 
     /// @brief Count number of overflow bins.
     size_t countOverflowBins(const size_t axisN) const noexcept;
@@ -189,7 +195,14 @@ namespace YODA {
     /// @brief Check if bin is masked
     bool isMasked(const size_t i) const noexcept;
 
+    /// @brief Calculates indices of visible bins.
+    ///
+    /// @note Masked bins still treated as (in principle) visible
+    std::vector<size_t> visibleBins() const noexcept;
+
     /// @brief Check if bin is in visible range
+    ///
+    /// @note Masked bins still treated as (in principle) visible
     bool isVisible(const size_t i) const noexcept;
 
     /// @brief Calculates size of a binning slice.
@@ -201,7 +214,7 @@ namespace YODA {
     std::vector<size_t> sliceIndices(std::vector<std::pair<size_t, std::vector<size_t>>>) const noexcept;
 
     /// @brief Calculates indices of bins located in the slice corresponding to
-    /// bin at nBin at axis N.
+    /// bin at @a binN at @a axisN.
     std::vector<size_t> sliceIndices(size_t axisN, size_t binN) const noexcept;
 
     /// @brief Helper function to extract and mask index slices
@@ -228,18 +241,18 @@ namespace YODA {
                             _maskedIndices.end() );
     }
 
-    //@}
+    /// @}
 
     /// @name Transformations
 
-    // @{
+    /// @{
     template <size_t... AxisNs>
     void mergeBins(
       std::decay_t<decltype(AxisNs, std::declval<std::pair<size_t, size_t>>())>... mergeRanges) noexcept;
-    // @}
+    /// @}
 
     /// @name Comparisons to other Binning objects
-    //@{
+    /// @{
 
     /// @brief checks if Binnings are compatible
     ///
@@ -247,10 +260,10 @@ namespace YODA {
     /// and those axes have the same bin edges
     bool isCompatible(const Binning<Axes...>& other) const noexcept;
 
-    //@}
+    /// @}
 
     /// @name Getters
-    //@{
+    /// @{
 
     /// @brief Extracts axis corresponding to dimension. Const version
     template <size_t I>
@@ -278,7 +291,7 @@ namespace YODA {
     /// @brief Return a coordinate tuple for bin @a index
     EdgeTypesTuple edgeTuple(const size_t index) const noexcept;
 
-    /// @brief Templated version to get edges of axis N by value.
+    /// @brief Templated version to get edges of axis I by value.
     ///
     /// +-inf edges are included, depending on the value of @a includeOverflows
     /// Needed by axis-specific version from StatsMixin
@@ -296,7 +309,7 @@ namespace YODA {
       return axis.edges();
     }
 
-    /// @brief Templated version to get bin widths of axis N by reference.
+    /// @brief Templated version to get bin widths of axis I by value.
     ///
     /// Overflows are included depending on @a includeOverflows
     /// Needed by axis-specific version from AxisMixin
@@ -309,6 +322,45 @@ namespace YODA {
       return axis.widths(includeOverflows);
     }
 
+    /// @brief Templated version to get bin maxs of axis I by value.
+    ///
+    /// Overflows are included depending on @a includeOverflows
+    /// Needed by axis-specific version from AxisMixin
+    ///
+    /// @note This version is only supported for continuous axes.
+    template <size_t I, typename E = getEdgeT<I>>
+    std::enable_if_t<std::is_floating_point<E>::value, std::vector<E>>
+    maxs(const bool includeOverflows = false) const noexcept {
+      const auto& axis = std::get<I>(_axes);
+      return axis.maxs(includeOverflows);
+    }
+
+    /// @brief Templated version to get bin mins of axis I by value.
+    ///
+    /// Overflows are included depending on @a includeOverflows
+    /// Needed by axis-specific version from AxisMixin
+    ///
+    /// @note This version is only supported for continuous axes.
+    template <size_t I, typename E = getEdgeT<I>>
+    std::enable_if_t<std::is_floating_point<E>::value, std::vector<E>>
+    mins(const bool includeOverflows = false) const noexcept {
+      const auto& axis = std::get<I>(_axes);
+      return axis.mins(includeOverflows);
+    }
+
+    /// @brief Templated version to get bin mids of axis I by value.
+    ///
+    /// Overflows are included depending on @a includeOverflows
+    /// Needed by axis-specific version from AxisMixin
+    ///
+    /// @note This version is only supported for continuous axes.
+    template <size_t I, typename E = getEdgeT<I>>
+    std::enable_if_t<std::is_floating_point<E>::value, std::vector<E>>
+    mids(const bool includeOverflows = false) const noexcept {
+      const auto& axis = std::get<I>(_axes);
+      return axis.mids(includeOverflows);
+    }
+
     /// @brief Get the lowest non-overflow edge of the axis
     ///
     /// @note This method is only supported for continuous axes
@@ -332,7 +384,7 @@ namespace YODA {
     /// @brief Return the differential volume for bin @a index
     double dVol(const size_t index) const;
 
-    //@}
+    /// @}
 
     /// @name I/O
     /// @{
@@ -377,7 +429,7 @@ namespace YODA {
       MetaUtils::staticFor<Dimension::value>(edgePrinter);
     }
 
-    //@}
+    /// @}
 
   };
 
@@ -448,7 +500,7 @@ namespace YODA {
   }
 
   template<typename... Axes>
-  std::vector<size_t> Binning<Axes...>::calcOverflowBinsIndices() const noexcept {
+  std::vector<size_t> Binning<Axes...>::overflowBins() const noexcept {
     IndexArr axesSizes = _getAxesSizes();
     std::vector<bool> isCAxis;
 
@@ -549,10 +601,26 @@ namespace YODA {
     return  std::find(_maskedIndices.cbegin(), itEnd, i) != itEnd;
   }
 
-  // @todo Should this also check if the bin is masked?
+  template<typename... Axes>
+  std::vector<size_t> Binning<Axes...>::visibleBins() const noexcept {
+    std::vector<size_t> res;
+    res.reserve(numBins(false));
+
+    const std::vector<size_t> overflows = overflowBins();
+    const auto& itEnd = overflows.cend();
+
+    size_t nBins = numBins();
+    for (size_t i=0; i<nBins; ++i) {
+      if (std::find(overflows.cbegin(), itEnd, i) == itEnd) {
+        res.push_back(i);
+      }
+    }
+    return res;
+  }
+
   template<typename... Axes>
   bool Binning<Axes...>::isVisible(const size_t i) const noexcept {
-    const std::vector<size_t> overflows = calcOverflowBinsIndices();
+    const std::vector<size_t> overflows = overflowBins();
     const auto& itEnd = overflows.cend();
     return  std::find(overflows.cbegin(), itEnd, i) == itEnd;
   }
