@@ -17,7 +17,6 @@
 #include <algorithm>
 #include <iostream>
 
-
 namespace YODA {
 
 
@@ -26,6 +25,7 @@ namespace YODA {
   public:
 
     using ValuePair = std::pair<double,double>;
+    using Pair = std::pair<double,double>;
 
 
     /// Virtual destructor for inheritance
@@ -44,6 +44,8 @@ namespace YODA {
     /// Set the point value for direction @a i
     virtual void setVal(const size_t i, const double val) = 0;
 
+    /// Clear the point values and errors
+    virtual void clear() = 0;
     /// @}
 
 
@@ -71,13 +73,23 @@ namespace YODA {
     /// Set positive error for direction @a i
     virtual void setErrPlus(const size_t i, const double eplus) = 0;
 
-    /// Get average error value for direction @a i
-    //virtual double errAvg(size_t i) const = 0;
+    /// Get error values along axis @a i
+    virtual Pair errs(const size_t i) const = 0;
 
-    // /// Get value minus negative error for direction @a i
-    // double min(size_t i) const = 0;
-    // /// Get value plus positive error for direction @a i
-    // double max(size_t i) const = 0;*/
+    /// Get the minus error along axis @a i
+    virtual double errMinus(const size_t i) const = 0;
+
+    /// Get the plus error along axis @a i
+    virtual double errPlus(const size_t i) const = 0;
+
+    /// Get average error value for direction @a i
+    virtual double errAvg(const size_t i) const = 0;
+
+    /// Get value minus negative error along axis @a i
+    virtual double min(const size_t i) const = 0;
+
+    /// Get value plus positive error along axis @a i
+    virtual double max(const size_t i) const = 0;
 
     /// @}
 
@@ -100,9 +112,15 @@ namespace YODA {
     /// @name Manipulations
     /// @{
 
-    // /// Scaling of direction @a i
+    /// Scaling of direction @a i
     virtual void scale(const size_t i, const double scale) = 0;
 
+    /// Scaling value along direction @a i
+    virtual void scaleVal(const size_t i, const double scale) = 0;
+
+    /// Scaling error along direction @a i
+    virtual void scaleErr(const size_t i, const double scale) = 0;
+
     //template<typename FN>
     //void scale(size_t i, FN f) = 0;
 
@@ -151,7 +169,7 @@ namespace YODA {
     /// @name Constructors
     /// @{
 
-    // @brief Default constructor
+    /// @brief Default constructor
     PointBase() {
       clear();
     }
@@ -443,7 +461,7 @@ namespace YODA {
     /// @}
 
     /// @name MPI (de-)serialisation
-    //@{
+    /// @{
 
     std::vector<double> _serializeContent() const noexcept {
       std::vector<double> rtn;
@@ -468,7 +486,7 @@ namespace YODA {
 
     }
 
-    // @}
+    /// @}
 
   protected:
 
@@ -638,7 +656,7 @@ namespace YODA {
     /// @}
 
 
-    // @name Manipulations
+    /// @name Manipulations
     /// @{
 
     /// Scaling of both axes
@@ -695,7 +713,7 @@ namespace YODA {
 
     /// @}
 
-    // @name Manipulations
+    /// @name Manipulations
     /// @{
 
     /// Scaling of both axes
