@@ -1,7 +1,7 @@
 // -*- C++ -*-
 //
 // This file is part of YODA -- Yet more Objects for Data Analysis
-// Copyright (C) 2008-2024 The YODA collaboration (see AUTHORS for details)
+// Copyright (C) 2008-2025 The YODA collaboration (see AUTHORS for details)
 //
 #ifndef YODA_READERFLAT_H
 #define YODA_READERFLAT_H
@@ -32,6 +32,12 @@ namespace YODA {
 
   private:
 
+    // Suppress H5 read method
+    #ifdef HAVE_HDF5
+    void read(const YODA_H5::File&, std::vector<AnalysisObject*>&,
+              const std::string& = "", const std::string& = "") { };
+    #endif
+
     /// Private constructor, since it's a singleton.
     ReaderFLAT() { }
 
