@@ -41,6 +41,7 @@ using std::vector;
 
 namespace YODA {
 
+
   /// Anonymous namespace to limit visibility
   namespace {
 
@@ -446,7 +447,7 @@ namespace YODA {
     public:
 
     void parse(const string& line) {
-      if (line.find("Total") != string::npos) {
+      if (line.rfind("Total", 0) == 0) {
         isYODA1 = true;
         return; // YODA1 backwards compatibility
       }
@@ -536,8 +537,9 @@ namespace YODA {
       loadEdges<0>(h5file);
       maskedBins = h5file.loadMasks();
       vector<string> annos = h5file.loadAnnotations();
-      auto args = std::tuple_cat(edges, std::make_tuple(h5file.path(), annos.back()));
+      auto args = std::tuple_cat(edges, std::make_tuple(h5file.path()));
       BaseT* ao = make_from_tuple(std::move(args));
+      ao->setTitle(annos.back());
       annos.pop_back();
       ao->deserializeMeta(annos);
       ao->deserializeContent(h5file.loadContent());
@@ -685,8 +687,9 @@ namespace YODA {
       maskedBins = h5file.loadMasks();
 
       vector<string> annos = h5file.loadAnnotations();
-      auto args = std::tuple_cat(edges, std::make_tuple(h5file.path(), annos.back()));
+      auto args = std::tuple_cat(edges, std::make_tuple(h5file.path()));
       BaseT* ao = make_from_tuple(std::move(args));
+      ao->setTitle(annos.back());
       annos.pop_back();
       ao->deserializeMeta(annos);
       ao->deserializeContent(h5file.loadContent());
