@@ -1,7 +1,7 @@
 // -*- C++ -*-
 //
 // This file is part of YODA -- Yet more Objects for Data Analysis
-// Copyright (C) 2008-2024 The YODA collaboration (see AUTHORS for details)
+// Copyright (C) 2008-2025 The YODA collaboration (see AUTHORS for details)
 //
 #ifndef YODA_WRITERFLAT_H
 #define YODA_WRITERFLAT_H
@@ -29,6 +29,10 @@ namespace YODA {
 
   private:
 
+    #ifdef HAVE_HDF5
+    void writeAOS(YODA_H5::File&, const vector<const AnalysisObject*>&) { };
+    #endif
+
     void _writeAnnotations(std::ostream& os, const AnalysisObject& ao);
 
     /// Private since it's a singleton.
