@@ -1,7 +1,7 @@
 // -*- C++ -*-
 //
 // This file is part of YODA -- Yet more Objects for Data Analysis
-// Copyright (C) 2008-2024 The YODA collaboration (see AUTHORS for details)
+// Copyright (C) 2008-2025 The YODA collaboration (see AUTHORS for details)
 //
 #ifndef YODA_WRITERYODA1_H
 #define YODA_WRITERYODA1_H
@@ -16,7 +16,7 @@
 namespace YODA {
 
 
-  /// Persistency writer for YODA flat text format.
+  /// Legacy persistency writer for YODA1-style flat text format.
   class [[deprecated]] WriterYODA1 : public Writer {
   public:
 
@@ -29,7 +29,8 @@ namespace YODA {
 
   protected:
 
-    void writeAO(std::ostream& stream, const AnalysisObject& c);
+    void writeAO(std::ostream& stream, const AnalysisObject& ao);
+
     void writeCounter(std::ostream& stream, const Counter& c);
     void writeHisto1D(std::ostream& stream, const Histo1D& h);
     void writeHisto2D(std::ostream& stream, const Histo2D& h);
@@ -42,6 +43,10 @@ namespace YODA {
 
   private:
 
+    #ifdef HAVE_HDF5
+    void writeAOS(YODA_H5::File&, const vector<const AnalysisObject*>&) { };
+    #endif
+
     void _writeAnnotations(std::ostream& os, const AnalysisObject& ao);
 
     /// Private since it's a singleton.
