@@ -1,3 +1,4 @@
+import sys
 import matplotlib.pyplot as plt
 from matplotlib.pyplot import Axes
 import numpy as np
@@ -83,8 +84,6 @@ def mkCurves2D(aos_dict, plot_ref=True, error_bars=True, colors=[],
     if plot_ref:
         #suff = ",\n                    norm=mpl.colors.LogNorm())" \
         #suff = ",\n                    locator=mpl.ticker.LogLocator())" \
-        suff = ",\n                   norm=mpl.colors.LogNorm(vmin=Z.min(), vmax=Z.max()))" \
-               if kwargs['logz'] else ")"
         cmd.add(f"# reference data in main panel",
                 f"cmap = '{colormap}'", # TODO This needs to be configurable from the outside
                 f"xbin_cent = np.unique(dataf['xpoints'])",
@@ -94,10 +93,10 @@ def mkCurves2D(aos_dict, plot_ref=True, error_bars=True, colors=[],
         zvalstr = 'Z.T' if transposeZ else 'Z'
         cmd.add(f"Z = np.array(dataf['zpoints']).reshape({xshapestr})",
                 f"pc = ax.pcolormesh(X, Y, {zvalstr}, cmap=cmap, shading='auto',",
-                f"                   vmin=zLims[0], vmax=zLims[1]"+suff,
+                f"                   norm=mpl.colors.LogNorm(vmin=zLims[0], vmax=zLims[1]))" \
+                if kwargs['logz'] else f"                   vmin=zLims[0], vmax=zLims[1])",
                 f"cbar = fig.colorbar(pc, orientation='vertical', ax=ax, pad=0.01)",#+suff,
                 f"cbar.set_label(ax_zLabel)")
-
     #
     c_zvals, c_zerrs, c_zups, c_zdowns, c_styles = {}, {}, {}, {}, {}
     if contourlevel is not None:
@@ -311,7 +310,8 @@ def mkCurves1D(aos, ratio_panels, error_bars=True, variation_dict=None,
             bandcol = ao.annotation(pre+'ErrorBandColor', ao.annotation('ErrorBandColor', colors[colidx])).split()
             bandstyle = ao.annotation(pre+'ErrorBandStyle', ao.annotation('ErrorBandStyle', None))
             bandstyle = [None] if bandstyle is None else bandstyle.split()
-            bandopac = list(ao.annotation(pre+'ErrorBandOpacity', ao.annotation('ErrorBandOpacity', [0.2])))
+            bandopac = ao.annotation(pre+'ErrorBandOpacity', ao.annotation('ErrorBandOpacity', [0.2]))
+            if not isinstance(bandopac, list):  bandopac = [ bandopac ]
             for s, sigma in enumerate(hasBand[rlabel[:-1] if pre else 'main']):
                 styles[k].update({
                     rlabel+sigma+'bandcolor'   : bandcol[0] if len(bandcol) == 1 else bandcol[-1-s],
@@ -345,8 +345,8 @@ def mkCurves1D(aos, ratio_panels, error_bars=True, variation_dict=None,
     data.add(f"]\n")
 
     writeLists(data, 'yvals',  yvals)
-    writeLists(data, 'xerrs', xups, xdowns)
-    writeLists(data, 'yerrs', yups, ydowns)
+    writeLists(data, 'xerrs', xdowns, xups)
+    writeLists(data, 'yerrs', ydowns, yups)
 
     # write out values for band and/or variation curves
     if hasBand['main']:
@@ -479,8 +479,8 @@ def mkCurves1D(aos, ratio_panels, error_bars=True, variation_dict=None,
             ratio_yvals[k] = ratio
 
         # write lists to read in executable py script
-        writeLists(data, f'{prefix}_yvals',  ratio_yvals)
-        writeLists(data, f'{prefix}_yerrs', ratio_yups, ratio_ydowns)
+        writeLists(data, f'{prefix}_yvals', ratio_yvals)
+        writeLists(data, f'{prefix}_yerrs', ratio_ydowns, ratio_yups)
         if variation_dict:
             writeLists(data, f'{prefix}_variation_vals', ratio_variation_vals)
 
@@ -545,7 +545,10 @@ def mkCurves1D(aos, ratio_panels, error_bars=True, variation_dict=None,
 
 def writeArray(cmd, label, arr):
     """Take a label and array as input, return as a formatted string."""
-    np.set_printoptions(formatter={'float' : '{:.6e}'.format})
+    np.set_printoptions(
+        formatter={'float' : '{:.6e}'.format},
+        threshold=sys.maxsize
+    )
     indent = ' ' * (len(label) + 3)
     vals = np.array2string(arr, separator=", ").replace("\n", "\n"+indent)
     cmd.add(f"{label} = {vals}")
