@@ -12,10 +12,13 @@ mpl.use('Agg')
 import math, re
 import numpy as np
 
-RE_PATTERN_PATH = re.compile(r'PATH\[(.+?)\]')
-RE_PATTERN_NAME = re.compile(r'NAME\[(.+?)\]')
+
+RE_PATTERN_PATH = re.compile(r'PATH\[(.+)\]')
+RE_PATTERN_NAME = re.compile(r'NAME\[(.+)\]')
 RE_PATTERN_OPTS = re.compile(r':([^:/=]+=[^:/=]+)')
 RE_PATTERN_OVAL = re.compile(r'\w+=(.+)')
+RE_PATTERN_RPAN = re.compile(r'(\w+(?:\s\[[^\[\]]+\])?)')
+
 
 
 def setCanvas(cmd, fig_dims, margins, nRatios = 0, fig_specs = None):
@@ -126,9 +129,9 @@ def mkPlottingScript1D(hist_data, hist_features, yaml_dicts, outdir, plot_name,
 
     cmd.add("# plot metadata",
             f"""figW, figH = plt.rcParams['figure.figsize']""",
-            f"""ax_xLabel = r'{plot_features.get("XLabel", "")}'""",
-            f"""ax_yLabel = r'{plot_features.get("YLabel", "")}'""",
-            f"""ax_title  = r'{plot_features.get("Title", "")}'""")
+            f"""ax_xLabel = {plot_features.get("XLabel", "")!r}""",
+            f"""ax_yLabel = {plot_features.get("YLabel", "")!r}""",
+            f"""ax_title  = {plot_features.get("Title", "")!r}""")
 
     ax_format = {}  # Stores the items for formatting the axes in a dict
     ax_format['logx'] = int(plot_features.get('LogX', 0))
@@ -273,7 +276,7 @@ def mkPlottingScript1D(hist_data, hist_features, yaml_dicts, outdir, plot_name,
             ratio_panels[label] = [ list(hist_data.keys())[0] ]
         ratio_lines = plot_features.get(label + 'DrawOnly', None)
         if ratio_lines is not None:
-            for rcurve in ratio_lines.split():
+            for rcurve in RE_PATTERN_RPAN.findall(ratio_lines):
                 if label in ratio_panels:
                     ratio_panels[label].append( rcurve )
                 else:
@@ -697,8 +700,23 @@ def mkPlottingScript2D(hist_data, hist_features, yaml_dicts, outdir,
     xmax = plot_features.get('XMax', max([max(h.xMaxs()) for h in hist_data.values()]))
     ymin = plot_features.get('YMin', min([min(h.yMins()) for h in hist_data.values()]))
     ymax = plot_features.get('YMax', max([max(h.yMaxs()) for h in hist_data.values()]))
-    zmin = plot_features.get('ZMin', min([min(h.zMins()) for h in hist_data.values()]))
-    zmax = plot_features.get('ZMax', max([max(h.zMaxs()) for h in hist_data.values()]))
+    zmin = plot_features.get('ZMin', min([min(h.zVals()) for h in hist_data.values()]))
+    zmax = plot_features.get('ZMax', max([max(h.zVals()) for h in hist_data.values()]))
+
+    if plot_features.get('LogX', 1):
+        xmax = xmax if xmax > 0 else 1.0
+        xmin = xmin if xmin > 0 else 0.1*xmax
+    if plot_features.get('LogY', 1):
+        ymax = ymax if ymax > 0 else 1.0
+        ymin = ymin if ymin > 0 else 0.1*ymax
+    if plot_features.get('LogZ', 1):
+        zmax = zmax if zmax > 0 else 1.0
+        zmin = zmin if zmin > 0 else 0.1*zmax
+
+    if math.isclose(xmin, xmax):  xmax = 10*xmin if xmin else 1.0
+    if math.isclose(ymin, ymax):  ymax = 10*ymin if ymin else 1.0
+    if math.isclose(zmin, zmax):  zmax = 10*zmin if zmin else 1.0
+
     ax_format['xlim'] = (float(xmin), float(xmax))
     ax_format['ylim'] = (float(ymin), float(ymax))
     ax_format['zlim'] = (float(zmin), float(zmax))
@@ -957,6 +975,10 @@ def _apply_regexes(features, regex_captures, regex_subs):
     for label in features:
         if any(label.endswith(sub) for sub in ('Title', 'Label', 'CustomMajorTicks')):
             features[label] = applyRegexes(features[label], regex_captures, regex_subs)
+        if label.startswith('text_'):
+            for tlabel, tvalue in features[label].items():
+                if tlabel.endswith('Text'):
+                    features[label][tlabel] = applyRegexes(features[label][tlabel], regex_captures, regex_subs)
 
 
 class AnyObject(object):
