@@ -1,7 +1,3 @@
-# -*- python -*-
-
-from __future__ import print_function
-
 try:
     from yoda.rootcnv import *
 except ImportError as e:
