@@ -305,15 +305,15 @@ def _S2toTGraph(s2d):
 
 
 def _H1toTGraph(h1d, binwidthdiv, usefocus, includeOverflows, includeHiddenBins):
-    return _S2toTGraph(h1d.mkScatter(h1d.path(), binwidthdiv, usefocus, includeOverflows, includeMaskedBins))
+    return _S2toTGraph(h1d.mkScatter(h1d.path(), binwidthdiv, usefocus, includeOverflows, includeHiddenBins))
 
 
 def _P1toTGraph(p1d, binwidthdiv, usefocus, includeOverflows, includeHiddenBins):
-    return _S2toTGraph(p1d.mkScatter(p1d.path(), binwidthdiv, usefocus, includeOverflows, includeMaskedBins))
+    return _S2toTGraph(p1d.mkScatter(p1d.path(), binwidthdiv, usefocus, includeOverflows, includeHiddenBins))
 
 
 def _E1toTGraph(e1d, includeOverflows, includeHiddenBins):
-    return _S2toTGraph(e1d.mkScatter(e1d.path(), includeOverflows, includeMaskedBins))
+    return _S2toTGraph(e1d.mkScatter(e1d.path(), includeOverflows, includeHiddenBins))
 
 
 def to_root(yoda_obj, asgraph=False, usefocus=False, widthscale=False,
