@@ -16,7 +16,7 @@ def match_aos(aos, patts, unpatts=None, search=False):
 
     ## Internally we just use the list of AOs, not dict keys
     if type(aos) is dict:
-        aos = list(aos.values()) #< TODO: maybe iter would be ok?
+        aos = aos.values()
 
     ## Normalise the pattern arg inputs
     if patts and type(patts) is str:
