@@ -1,11 +1,15 @@
 // -*- C++ -*-
 //
 // This file is part of YODA -- Yet more Objects for Data Analysis
-// Copyright (C) 2008-2024 The YODA collaboration (see AUTHORS for details)
+// Copyright (C) 2008-2025 The YODA collaboration (see AUTHORS for details)
 //
 #include "YODA/ReaderYODA.h"
 #include "YODA/ReaderFLAT.h"
-#include "YODA/Config/DummyConfig.h"
+#include "YODA/Config/BuildConfig.h"
+
+#ifdef HAVE_HDF5
+#include "YODA/ReaderH5.h"
+#endif
 
 using namespace std;
 
@@ -24,6 +28,9 @@ namespace YODA {
       fmt = Utils::toLower(lastbutonedot == string::npos ? name : name.substr(lastbutonedot+1));
     }
     // Create the appropriate Reader
+    #ifdef HAVE_HDF5
+    if (Utils::startswith(fmt, "h5"))   return ReaderH5::create();
+    #endif
     if (Utils::startswith(fmt, "yoda")) return ReaderYODA::create();
     if (Utils::startswith(fmt, "dat" )) return ReaderFLAT::create(); ///< @todo Improve/remove... .ydat?
     if (Utils::startswith(fmt, "flat")) return ReaderFLAT::create();
