@@ -117,6 +117,8 @@ namespace YODA {
     string fmt = "1";
     //int nfmt = 1;
 
+    bool legacy_transpose = false;
+
     while (Utils::getline(stream, s)) {
       nline += 1;
 
@@ -185,6 +187,9 @@ namespace YODA {
 
         // From version 2 onwards, use the in_anns state from BEGIN until ---
         if (fmt != "1") in_anns = true;
+        if (fmt == "1" || fmt == "2") {
+          if (typestr == "SCATTER3D")  legacy_transpose = true;
+        }
 
       }
       else if (s.find("BEGIN ") != string::npos) { ///< @todo require pos = 0 from fmt=V2
@@ -193,6 +198,7 @@ namespace YODA {
       else if (s.find("END ") != string::npos) { ///< @todo require pos = 0 from fmt=V2
 
         if (!pattern_pass) {
+          legacy_transpose = false;
           pattern_pass = true;
           typestr = "";
           continue;
@@ -222,6 +228,7 @@ namespace YODA {
           // cerr << err << endl;
           throw ReadError(err);
         }
+        if (legacy_transpose)  aocurr->setAnnotation("YODA1_ZVAL_LAYOUT", 1);
         annscurr.clear();
         in_anns = false;
 
