@@ -109,6 +109,14 @@ int main() {
   }
   MSG_GREEN("PASS");
 
+  MSG_(PAD(70) << "Checking fill with coord group: ");
+  h.fill(Histo1D::FillType{50.}, 10);
+  if (h.bin(51).sumW() != 10) {
+    MSG_RED("FAIL");
+    return -1;
+  }
+  MSG_GREEN("PASS");
+
 
   // MSG_(PAD(70) << "Trying to fill with inf: ");
   // h.fill(numeric_limits<double>::infinity(),1);
