@@ -1,4 +1,4 @@
-#include "YODA/Histo1D.h"
+#include "YODA/Histo.h"
 #include "YODA/Utils/Formatting.h"
 
 using namespace YODA;
@@ -12,7 +12,7 @@ int main() {
   MSG_GREEN("PASS");
 
   MSG_(PAD(70) << "Trying to merge bins: ");
-  h.mergeBins(0, 10);
+  h.mergeBins<0>({0, 10});
   MSG_GREEN("PASS");
 
   MSG_(PAD(70) << "Testing if bin number was updated: ");
@@ -23,14 +23,14 @@ int main() {
   MSG_GREEN("PASS");
 
   MSG_(PAD(70) << "Checking if bin size was updated: ");
-  if (!fuzzyEquals(h.bin(0).xMin(), 0) || !fuzzyEquals(h.bin(0).xMax(), 11)) {
+  if (h.bin(0).xMin() != -std::numeric_limits<double>::infinity() || !fuzzyEquals(h.bin(0).xMax(), 10)) {
     MSG_RED("FAIL");
     return -1;
   }
   MSG_GREEN("PASS");
 
   MSG_(PAD(70) << "Checking if bin removal works: ");
-  h.eraseBin(0);
+  h.maskBin(1);
   MSG_GREEN("PASS");
 
   MSG_(PAD(70) << "Was the bin number updated properly? ");
@@ -47,17 +47,6 @@ int main() {
   }
   MSG_GREEN("PASS");
 
-  MSG_(PAD(70) << "Checking if it is possible to add a bin: ");
-  h.addBin(0, 11);
-  MSG_GREEN("PASS");
-
-  MSG_(PAD(70) << "Checking if it was added properly: ");
-  if (!fuzzyEquals(h.bin(0).xMin(), 0) || !fuzzyEquals(h.bin(0).xMax(),11)) {
-    MSG_RED("FAIL");
-    return -1;
-  }
-  MSG_GREEN("PASS");
-
   MSG_(PAD(70) << "Checking the reset function: ");
   h.reset();
   if (h.integral() != 0) {
