@@ -30,6 +30,13 @@ int main() {
   }
   MSG_GREEN("PASS");
 
+  MSG_(PAD(70) << "Filling using coordinate group ");
+  p1.fill(Profile1D::FillType{50.,50.}, 10);
+  if (p1.binAt(50.).sumW() != 10){
+    MSG_RED("FAIL");
+    return -1;
+  }
+  MSG_GREEN("PASS");
 
   MSG_(PAD(70) << "Preliminary testing of = operator ");
   Profile1D p3(edges);
@@ -44,5 +51,13 @@ int main() {
   }
   MSG_GREEN("PASS");
 
+  MSG_(PAD(70) << "Testing of newclone ");
+  Profile1D* pptr = p3.newclone();
+  if (pptr == nullptr) {
+    MSG_RED("FAIL");
+    return -1;
+  }
+  MSG_GREEN("PASS");
+
   return EXIT_SUCCESS;
 }
