@@ -11,6 +11,14 @@ using namespace YODA;
 auto testCounter() {
   Counter c1;
 
+  if (c1.fillDim())  return CHECK_TEST_RES(false);
+
+  c1.fill();
+  if (!isZero(c1.numEntries()-1.0))  return CHECK_TEST_RES(false);
+
+  c1.reset();
+  if (!isZero(c1.effNumEntries()))  return CHECK_TEST_RES(false);
+
   const size_t N = 10000;
   for (size_t i=0; i<N; ++i)  c1.fill(10.0);
 
