@@ -6,6 +6,7 @@
 #include "YODA/Profile.h"
 #include "YODA/WriterYODA.h"
 #include "YODA/WriterFLAT.h"
+#include "YODA/Utils/MathUtils.h"
 #include "YODA/Utils/TestHelpers.h"
 #include <string>
 #include <iostream>
@@ -219,6 +220,23 @@ auto testRebinning(Histo2D& h2) {
   }
   std::cout << std::endl;
 
+  Histo1D h3(linspace(20, 0., 100.));
+  std::cout << "x-edges before:" << std::endl;
+  for (double edge : h3.xEdges()) {
+    std::cout << "\t" << edge;
+  }
+  std::cout << std::endl;
+  std::vector<double> mixed_edges = linspace(10, 0., 50.);
+  std::vector<double> toAppend = linspace(4, 60., 100.);
+  mixed_edges.insert(mixed_edges.end(), toAppend.begin(), toAppend.end());
+  h3.rebinX(mixed_edges);
+  std::cout << "x-edges after:" << std::endl;
+  for (double edge : h3.xEdges()) {
+    std::cout << "\t" << edge;
+  }
+  std::cout << std::endl;
+
+
   return CHECK_TEST_RES(true);
 }
 
