@@ -22,5 +22,14 @@ int main() {
        << boolalpha << (iset[3] == 4)
        << endl;
 
+  bool fail = true;
+  try {
+    iset[5];
+  }
+  catch (const range_error&) {
+    fail = false;
+  }
+  if (fail) return EXIT_FAILURE;
+
   return (iset[3] == 4) ? EXIT_SUCCESS : EXIT_FAILURE;
 }
