@@ -9,7 +9,7 @@ using namespace YODA;
 auto testPaths() {
 
   const std::string libPath = getLibPath();
-  if ( !Utils::endswith(libPath, "/lib") )  return CHECK_TEST_RES(false);
+  if ( !Utils::endswith(libPath, "/lib") && !Utils::endswith(libPath, "/lib64") )  return CHECK_TEST_RES(false);
 
   const std::string dataPath = getDataPath();
   if ( !Utils::endswith(dataPath, "/share/YODA") )  return CHECK_TEST_RES(false);
