@@ -143,6 +143,51 @@ int main() {
     return -1;
   }
 
+  cout << "Check virtual base class methods: " << endl;
+  Point *p = new Point3D(1, 2, 3, err, err, err);
+  if (p->dim() != p4.dim() ||
+      !fuzzyEquals(p->val(0), p4.x()) ||
+      !fuzzyEquals(p->val(1), p4.y()) ||
+      !fuzzyEquals(p->val(2), p4.z()) ||
+      !fuzzyEquals(p->errMinus(0), p4.xErrMinus()) ||
+      !fuzzyEquals(p->errPlus(0), p4.xErrPlus()) ||
+      !fuzzyEquals(p->errMinus(1), p4.yErrMinus()) ||
+      !fuzzyEquals(p->errPlus(1), p4.yErrPlus()) ||
+      !fuzzyEquals(p->errMinus(2), p4.zErrMinus()) ||
+      !fuzzyEquals(p->errPlus(2), p4.zErrPlus()) ||
+      !fuzzyEquals(p->min(0), p4.xMin()) ||
+      !fuzzyEquals(p->min(1), p4.yMin()) ||
+      !fuzzyEquals(p->min(2), p4.zMin()) ||
+      !fuzzyEquals(p->max(0), p4.xMax()) ||
+      !fuzzyEquals(p->max(1), p4.yMax()) ||
+      !fuzzyEquals(p->max(2), p4.zMax())) {
+    cout << "Point base accessor methods do not work correctly!" << endl;
+    return -1;
+  }
+  p->setVal(0, 10.0);
+  p->setErr(0, 10.0);
+  p->scaleVal(0, 2);
+  p->scaleErr(0, 3);
+  if (!fuzzyEquals(p->val(0), 20.) || !fuzzyEquals(p->errPlus(0), 30.)) {
+    cout << "Point base scaling methods do not work correctly!" << endl;
+    return -1;
+  }
+  p->set(0, 1.0, 0.1);
+  p->set(1, 10.0, 0.2, 0.3);
+  p->set(2, 100.0, errpair);
+  if (!fuzzyEquals(p->val(0), 1.0)   || !fuzzyEquals(p->errPlus(0), 0.1) ||
+      !fuzzyEquals(p->val(1), 10.0)  || !fuzzyEquals(p->errPlus(1), 0.3) ||
+      !fuzzyEquals(p->val(2), 100.0) || !fuzzyEquals(p->errPlus(2), 0.5)) {
+    cout << "Point base state-setting methods do not work correctly!" << endl;
+    return -1;
+  }
+  p->clear();
+  if (!isZero(p->val(0)) || !isZero(p->errPlus(0))) {
+    cout << "Point base clear method does not work correctly!" << endl;
+    return -1;
+  }
+  delete p;
+
   cout << "And a quick performance check: " << endl;
   struct timeval startTime;
   struct timeval endTime;
