@@ -5,7 +5,9 @@
 #include "YODA/Scatter.h"
 #include "YODA/WriterYODA.h"
 #include "YODA/WriterYODA1.h"
+#ifdef HAVE_HDF5
 #include "YODA/WriterH5.h"
+#endif
 #include <cmath>
 #include <vector>
 #include <iostream>
